pub struct Mul<L: Eval, R: Eval>(_, _);
Arithmetic multiplication (e.g. a * b)
Formats the value using the given formatter.
Read more
Fold an expression into a value.
Fold an expression into a value without consuming the expression.
Output of evaluation (i.e. eval() -> ???).
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.